==> torch-book-0.0.3.tar.gz: torch-book-0.0.3/README.md <==
# torch-book

[![PyPI][pypi-badge]][pypi-link]
[![GitHub issues][issue-badge]][issue-link]
[![GitHub forks][fork-badge]][fork-link]
[![GitHub stars][star-badge]][star-link]
[![GitHub license][license-badge]][license-link]
[![contributors][contributor-badge]][contributor-link]
[![watcher][watcher-badge]][watcher-link]
[![Binder][binder-badge]][binder-link]
[![Downloads][download-badge]][download-link]
[![Documentation Status][status-badge]][status-link]
[![PyPI - Downloads][install-badge]][install-link]
![repo size](https://img.shields.io/github/repo-size/xinetzone/torch-book.svg)
[![Downloads Week](https://pepy.tech/badge/torch-book/week)](https://pepy.tech/project/torch-book)
[![Documentation Status][rtd-badge]][rtd-link]

Torch 手册。

[pypi-badge]: https://img.shields.io/pypi/v/torch-book.svg
[pypi-link]: https://pypi.org/project/torch-book/
[issue-badge]: https://img.shields.io/github/issues/xinetzone/torch-book
[issue-link]: https://github.com/xinetzone/torch-book/issues
[fork-badge]: https://img.shields.io/github/forks/xinetzone/torch-book
[fork-link]: https://github.com/xinetzone/torch-book/network
[star-badge]: https://img.shields.io/github/stars/xinetzone/torch-book
[star-link]: https://github.com/xinetzone/torch-book/stargazers
[license-badge]: https://img.shields.io/github/license/xinetzone/torch-book
[license-link]: https://github.com/xinetzone/torch-book/LICENSE
[contributor-badge]: https://img.shields.io/github/contributors/xinetzone/torch-book
[contributor-link]: https://github.com/xinetzone/torch-book/contributors
[watcher-badge]: https://img.shields.io/github/watchers/xinetzone/torch-book
[watcher-link]: https://github.com/xinetzone/torch-book/watchers
[binder-badge]: https://mybinder.org/badge_logo.svg
[binder-link]: https://mybinder.org/v2/gh/xinetzone/torch-book/main
[install-badge]: https://img.shields.io/pypi/dw/torch-book?label=pypi%20installs
[install-link]: https://pypistats.org/packages/torch-book
[status-badge]: https://readthedocs.org/projects/torch-book/badge/?version=latest
[status-link]: https://torch-book.readthedocs.io/zh/latest/?badge=latest
[download-badge]: https://pepy.tech/badge/torch-book
[download-link]: https://pepy.tech/project/torch-book
[rtd-badge]: https://readthedocs.org/projects/torch-book/badge/?version=latest
[rtd-link]: https://torch-book.readthedocs.io/zh/latest/?badge=latest

## 支持 PyPI

需要安装 `torch-book` 包：

```shell
pip install torch-book
```

==> torch-book-0.0.5.tar.gz: torch-book-0.0.5/README.md <==
# torch-book

[![PyPI][pypi-badge]][pypi-link]
[![GitHub issues][issue-badge]][issue-link]
[![GitHub forks][fork-badge]][fork-link]
[![GitHub stars][star-badge]][star-link]
[![GitHub license][license-badge]][license-link]
[![contributors][contributor-badge]][contributor-link]
[![watcher][watcher-badge]][watcher-link]
[![Binder][binder-badge]][binder-link]
[![Downloads][download-badge]][download-link]
[![Documentation Status][status-badge]][status-link]
[![PyPI - Downloads][install-badge]][install-link]
![repo size](https://img.shields.io/github/repo-size/xinetzone/torch-book.svg)
[![Downloads Week](https://pepy.tech/badge/torch-book/week)](https://pepy.tech/project/torch-book)
[![Documentation Status][rtd-badge]][rtd-link]
[![Upload Python Package][upload-python-package-badge]][upload-python-package-link]

Torch 手册。

[upload-python-package-badge]: https://github.com/xinetzone/torch-book/actions/workflows/python-publish.yml/badge.svg
[upload-python-package-link]: https://github.com/xinetzone/torch-book/actions/workflows/python-publish.yml
[pypi-badge]: https://img.shields.io/pypi/v/torch-book.svg
[pypi-link]: https://pypi.org/project/torch-book/
[issue-badge]: https://img.shields.io/github/issues/xinetzone/torch-book
[issue-link]: https://github.com/xinetzone/torch-book/issues
[fork-badge]: https://img.shields.io/github/forks/xinetzone/torch-book
[fork-link]: https://github.com/xinetzone/torch-book/network
[star-badge]: https://img.shields.io/github/stars/xinetzone/torch-book
[star-link]: https://github.com/xinetzone/torch-book/stargazers
[license-badge]: https://img.shields.io/github/license/xinetzone/torch-book
[license-link]: https://github.com/xinetzone/torch-book/LICENSE
[contributor-badge]: https://img.shields.io/github/contributors/xinetzone/torch-book
[contributor-link]: https://github.com/xinetzone/torch-book/contributors
[watcher-badge]: https://img.shields.io/github/watchers/xinetzone/torch-book
[watcher-link]: https://github.com/xinetzone/torch-book/watchers
[binder-badge]: https://mybinder.org/badge_logo.svg
[binder-link]: https://mybinder.org/v2/gh/xinetzone/torch-book/main
[install-badge]: https://img.shields.io/pypi/dw/torch-book?label=pypi%20installs
[install-link]: https://pypistats.org/packages/torch-book
[status-badge]: https://readthedocs.org/projects/torch-book/badge/?version=latest
[status-link]: https://torch-book.readthedocs.io/zh/latest/?badge=latest
[download-badge]: https://pepy.tech/badge/torch-book
[download-link]: https://pepy.tech/project/torch-book
[rtd-badge]: https://readthedocs.org/projects/torch-book/badge/?version=latest
[rtd-link]: https://torch-book.readthedocs.io/zh/latest/?badge=latest

## 支持 PyPI

需要安装 `torch-book` 包：

```shell
pip install torch-book
```
